__all__ = [
    "Attester",
    "EPSAttester",
]

import os
from abc import ABC, abstractmethod

import requests

from . import exceptions as exp


class Attester(ABC):
    @abstractmethod
    def get_evidence(self, report_data: str) -> bytes:
        raise NotImplementedError


class EPSAttester(Attester):
    def __init__(self) -> None:
        pass

    def get_evidence(self, report_data: str) -> bytes:
        eps_addr = os.environ.get("LOCAL_EPS_ADDR", "localhost:8006")
        url = "http://{}/aa/evidence?runtime_data={}".format(eps_addr, report_data)
        try:
            resp = requests.get(url=url)
            resp.raise_for_status()
        except requests.RequestException as e:
            raise exp.RAError("Bad connection to EPS '{}': {}".format(url, e)) from e

        return resp.content
